{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block form_attrs %}enctype="multipart/form-data"{% endblock %}


{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>
    {% trans "Enter the details for the languagepack." %}
  </p>
{% endblock %}
